@@ -83,8 +83,6 @@ class OccupationInsightResponse:
 
     @raw_response.setter
     def raw_response(self, raw_response: str) -> None:
-        if raw_response is not None and not isinstance(raw_response, str):
-            raise TypeError("raw_response must be a string")
         self.__raw_response = raw_response
 
     @property
@@ -93,8 +91,6 @@ class OccupationInsightResponse:
 
     @refresh_date.setter
     def refresh_date(self, refresh_date: str) -> None:
-        if refresh_date is not None and not isinstance(refresh_date, str):
-            raise TypeError("refresh_date must be a string")
         self.__refresh_date = refresh_date
 
     @property
@@ -125,8 +121,7 @@ class OccupationInsightResponse:
 
     @salary_min.setter
     def salary_min(self, salary_min: str) -> None:
-        if salary_min is not None and not isinstance(salary_min, float):
-            raise TypeError("salary_min must be a float")
+
         self.__salary_min = salary_min
 
     @property
@@ -135,8 +130,7 @@ class OccupationInsightResponse:
 
     @salary_max.setter
     def salary_max(self, salary_max: str) -> None:
-        if salary_max is not None and not isinstance(salary_max, float):
-            raise TypeError("salary_max must be a float")
+
         self.__salary_max = salary_max
 
     @property
@@ -145,8 +139,7 @@ class OccupationInsightResponse:
 
     @salary_median.setter
     def salary_median(self, salary_median: str) -> None:
-        if salary_median is not None and not isinstance(salary_median, float):
-            raise TypeError("salary_median must be a float")
+
         self.__salary_median = salary_median
 
     @property
